.. _selprotopy.exceptions.py:

Base Exceptions
===============

.. autoexception:: selprotopy.exceptions.CommError

.. autoexception:: selprotopy.exceptions.ParseError

.. autoexception:: selprotopy.exceptions.ProtoError


Communications Exceptions
=========================

.. autoexception:: selprotopy.exceptions.MalformedByteArray

.. autoexception:: selprotopy.exceptions.ChecksumFail

.. autoexception:: selprotopy.exceptions.ConnVerificationFail


Parse Errors
~~~~~~~~~~~~

.. autoexception:: selprotopy.exceptions.MissingA5Head

.. autoexception:: selprotopy.exceptions.DnaDigitalsMisMatch


Protocol Exceptions
===================

.. autoexception:: selprotopy.exceptions.InvalidCommandType

.. autoexception:: selprotopy.exceptions.InvalidControlType

